proxy — Health Dashboard

# proxy — Good

Analyzed 2026-03-21 by code2llm · Primary language: python · Python: 42, JavaScript: 5, Shell: 3

346
Functions
45
Classes
38
Files
11,178
Lines
3
Languages
3.5
Avg CC
14
Critical (CC≥10)
0
Duplicates
1
Cycles

## Language Distribution

## Largest Modules (lines)

## Most Complex Modules (functions)

## Evolution (2026-03-21)

3.5
CC̄ →
14
Critical →
11178
Lines

Run analysis multiple times to build a trend chart (≥3 data points needed).

## Top Modules (50)

Module | Path | Lines | Funcs | Classes | CC max
--- | --- | --- | --- | --- | ---
coverage_html_cb_dd2e7eb5.js | htmlcov | 735 | 65 | 0 | 21
_orchestrator.py | src/proxym/virt | 510 | 28 | 1 | 7
panel.jsx | src/proxym/dashboard | 347 | 26 | 0 | 13
__init__.py | src/proxym/accounts | 346 | 20 | 8 | 10
__init__.py | src/proxym/router | 340 | 14 | 1 | 8
__init__.py | src/proxym/cache | 333 | 10 | 3 | 9
__init__.py | src/proxym/providers | 330 | 4 | 3 | 8
browser_profiles.py | src/proxym/virt | 325 | 11 | 2 | 9
completions.py | src/proxym/api | 293 | 10 | 0 | 12
__init__.py | src/proxym/dashboard | 265 | 20 | 4 | 3
strategy.py | src/proxym/router | 253 | 14 | 3 | 9
clonebox_adapter.py | src/proxym/virt | 209 | 17 | 2 | 5
detector.py | src/proxym/context | 208 | 9 | 0 | 9
ctl.py | src/proxym | 179 | 2 | 0 | 7
client.py | src/proxym/mcp | 148 | 4 | 2 | 6
__init__.py | src/proxym/watch | 146 | 5 | 1 | 5
session.py | src/proxym/context | 144 | 8 | 2 | 6
main.py | src/proxym | 136 | 2 | 0 | 3
registry.py | src/proxym/mcp | 113 | 8 | 3 | 4
frontend.py | src/proxym/api | 108 | 6 | 0 | 5

## Alerts (20)

Severity | Target | Type | Value | Limit
--- | --- | --- | --- | ---
critical | main | high_fan_out | 26 | 10
critical | chat_completions | high_fan_out | 22 | 10
error | table | cc_exceeded | 21 | 15
error | table_body_rows | cc_exceeded | 21 | 15
error | no_rows | cc_exceeded | 21 | 15
error | footer | cc_exceeded | 21 | 15
error | ratio_columns | cc_exceeded | 21 | 15
error | filter_handler | cc_exceeded | 21 | 15
error | useDashboardData | high_fan_out | 18 | 10
error | detect_firefox_profiles | high_fan_out | 17 | 10
error | _detect_chromium_family | high_fan_out | 17 | 10
error | analyze_request | high_fan_out | 15 | 10
error | sortColumn | high_fan_out | 15 | 10
error | table | high_fan_out | 15 | 10
error | table_body_rows | high_fan_out | 15 | 10

## Hotspots (10)

Function | Fan-out | Note
--- | --- | ---
main | 26 | Orchestrates 26 calls
chat_completions | 22 | OpenAI-compatible chat completions with intelligent routing. Extra headers: X
useDashboardData | 18 | Orchestrates 18 calls
detect_firefox_profiles | 17 | Detect Firefox profiles by parsing profiles.ini.
_detect_chromium_family | 17 | Detect profiles for Chrome/Chromium from Local State file.
analyze_request | 15 | Analysis pipeline, 15 stages
sortColumn | 15 | Orchestrates 15 calls
table | 15 | Orchestrates 15 calls
table_body_rows | 15 | Orchestrates 15 calls
no_rows | 15 | Orchestrates 15 calls

## Refactoring Priorities (12)

# | Action | Impact | Effort
--- | --- | --- | ---
1 | Split god module htmlcov/coverage_html_cb_dd2e7eb5.js (735L, 0 classes) | high | high
2 | Split god module src/proxym/virt/_orchestrator.py (510L, 1 classes) | high | high
3 | Split table (CC=21 → target CC<10) | medium | low
4 | Split table_body_rows (CC=21 → target CC<10) | medium | low
5 | Split no_rows (CC=21 → target CC<10) | medium | low
6 | Split footer (CC=21 → target CC<10) | medium | low
7 | Split ratio_columns (CC=21 → target CC<10) | medium | low
8 | Split filter_handler (CC=21 → target CC<10) | medium | low
9 | Break circular dependency: src.proxym.virt.profiles.merge_profiles | medium | low
10 | Reduce main fan-out (currently 26) | medium | medium
11 | Reduce chat_completions fan-out (currently 22) | medium | medium
12 | Reduce useDashboardData fan-out (currently 18) | medium | medium